@@ -35,13 +35,14 @@ This class inherits from L<Perl::Dist::Asset> and shares its API.
 =cut
 
 use strict;
-use Carp         'croak';
-use Params::Util qw{ _STRING };
-use base 'Perl::Dist::Asset';
+use Carp              ();
+use Params::Util      qw{ _STRING };
+use Perl::Dist::Asset ();
 
-use vars qw{$VERSION};
+use vars qw{$VERSION @ISA};
 BEGIN {
-	$VERSION = '1.00';
+	$VERSION = '1.05_01';
+	@ISA     = 'Perl::Dist::Asset';
 }
 
 use Object::Tiny qw{
@@ -87,7 +88,7 @@ sub new {
 
 	# Check params
 	unless ( _STRING($self->install_to) ) {
-		croak("Missing or invalid install_to param");
+		Carp::croak("Missing or invalid install_to param");
 	}
 
 	return $self;
