@@ -6,7 +6,7 @@ use Params::Util qw{ _STRING };
 
 use vars qw{$VERSION};
 BEGIN {
-	$VERSION = '1.00';
+	$VERSION = '1.05_01';
 }
 
 use Object::Tiny qw{
@@ -62,9 +62,9 @@ sub content {
 sub write {
 	my $self = shift;
 	my $to   = shift;
-	open( WEBSITE, ">$to" ) or die "open($to): $!";
-	print WEBSITE $self->content;
-	close WEBSITE;
+	open( WEBSITE, ">$to" )      or die "open($to): $!";
+	print WEBSITE $self->content or die "print($to): $!";
+	close WEBSITE                or die "close($to): $!";
 	return 1;
 }
 
